/**
 *******************************************************************************
 * @file    main.c
 * @brief   The demo functions of ADC for the
 *          TOSHIBA 'TMPM333' Device Series 
 * @version V1.201
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

char tADC_Display[16];
uint32_t gADC_state = 0U;
ADC_ResultTypeDef gADC_Result;

int main(void)
{
    LCD_Configuration();
    LCD_Light(ON);

    ADC_SWReset();
    ADC_SetInputChannel(ADC_AN_0);
    ADC_SetRepeatMode(ENABLE);
    ADC_SetVref(ENABLE);
    ADC_Start();

    for (;;) {
        gADC_state = ADC_GetConvertState();
        if (DONE == gADC_state) {
            gADC_state = BUSY;
            gADC_Result = ADC_GetConvertResult(ADC_REG_08);
            ADC_Display(gADC_Result.ADCResultValue);
        }
    }
}

void ADC_Display(uint32_t e_Adc_Value)
{
    uint32_t e_volumn;
    uint32_t e_ADC_i;

    e_volumn = (e_Adc_Value * 100U) / 0x03ffU;  /* Max ADC is 0x03ff      */

    tADC_Display[0] = 'A';      /* Disaply: "ADC Value:   "     */
    tADC_Display[1] = 'D';
    tADC_Display[2] = 'C';
    tADC_Display[3] = ' ';
    tADC_Display[4] = 'V';
    tADC_Display[5] = 'a';
    tADC_Display[6] = 'l';
    tADC_Display[7] = 'u';
    tADC_Display[8] = 'e';
    tADC_Display[9] = ':';

    /*  Display the value                           */
    if (e_volumn >= 100U) {
        tADC_Display[10] = (char) ((e_volumn / 100U) + 0x30U);
        tADC_Display[11] = (char) (((e_volumn / 10U) % 10U) + 0x30U);
        tADC_Display[12] = (char) ((e_volumn % 10U) + 0x30U);
    } else {
        tADC_Display[10] = ' ';
        if (e_volumn / 10U) {
            tADC_Display[11] = (char) ((e_volumn / 10U) + 0x30U);
        } else {
            tADC_Display[11] = ' ';
        }
        tADC_Display[12] = (char) ((e_volumn % 10U) + 0x30U);
    }
    tADC_Display[13] = 0U;
    Send_To_LCD(FIRST_LINE, LCD_COMMAND);
    Send_LCD_Text(tADC_Display);

    /*  Display the value volumn percent, the 100% is 16 x '*'      */
    e_volumn = e_volumn * 16U;
    e_volumn = e_volumn / 100U;
    for (e_ADC_i = 0U; e_ADC_i < 16U; e_ADC_i++) {
        tADC_Display[e_ADC_i] = 0U;
    }

    for (e_ADC_i = 0U; e_ADC_i < e_volumn; e_ADC_i++) {
        tADC_Display[e_ADC_i] = '*';    /* Display "*" for volumn percent     */
    }
    e_ADC_i++;
    tADC_Display[e_ADC_i] = 0U; /* String end               */
    Send_To_LCD(SECOND_LINE, LCD_COMMAND);
    Send_LCD_Text(tADC_Display);
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
