/**
 *******************************************************************************
 * @file    key.c
 * @brief   KEY driver for the TOSHIBA 'TMPM333' Device Series
 * @version V0.201
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "key.h"

/*******************************************************************************
* Function Name  : KEY_Init
* Description    : Configure the GPIO to KEY 
* Input          : None 
* Return         : None.
*******************************************************************************/
void KEY_Init(void)
{
    GPIO_SetInput(GPIO_PB, GPIO_BIT_4);
    GPIO_SetInput(GPIO_PB, GPIO_BIT_5);
    GPIO_SetInput(GPIO_PB, GPIO_BIT_6);
    GPIO_SetInput(GPIO_PB, GPIO_BIT_7);

    GPIO_SetPullUp(GPIO_PB, GPIO_BIT_4, ENABLE);
    GPIO_SetPullUp(GPIO_PB, GPIO_BIT_5, ENABLE);
    GPIO_SetPullUp(GPIO_PB, GPIO_BIT_6, ENABLE);
    GPIO_SetPullUp(GPIO_PB, GPIO_BIT_7, ENABLE);
}

/*******************************************************************************
* Function Name  : KEY_Get
* Description    : Get KEY Value
* Input          : ucKEY.
* Return         : KEY value.
*******************************************************************************/
uint8_t KEY_Get(uint8_t ucKEY)
{
    uint8_t ucVal = 0U;
    if (ucKEY & KEY1) {
        if (!GPIO_ReadDataBit(GPIO_PB, GPIO_BIT_7)) {
            ucVal |= 0x01;
        }
    }
    if (ucKEY & KEY2) {
        if (!GPIO_ReadDataBit(GPIO_PB, GPIO_BIT_6)) {
            ucVal |= 0x02;
        }
    }
    if (ucKEY & KEY3) {
        if (!GPIO_ReadDataBit(GPIO_PB, GPIO_BIT_5)) {
            ucVal |= 0x04;
        }
    }
    if (ucKEY & KEY4) {
        if (!GPIO_ReadDataBit(GPIO_PB, GPIO_BIT_4)) {
            ucVal |= 0x08;
        }
    }
    return (ucVal);
}
